# Fermy
Fermy is a toolkit to empower fermentation data analysis from any SCADA.
Input data have to be converted in Python Pandas DataFrame with datetime or deltatime converted into float as index. 

- pandasfermy add to Pandas methods to compute analysis on fermentation data e.g. DataFrame.fermgrowth()
- plotlyfermy give Pandas methods to plot fermentation data e.g. DataFrame.ccplot().

The project is hosted at https://gitlab.com/

To install it: pip install fermy
